postgres.PostgresIndexStore

|  | ## Cheshire3 Object Model: Class PostgresIndexStore

Module postgres :: Class PostgresIndexStore

## Class PostgresIndexStore
source code

Object Tree:

                   object --+
                            |
        configParser.C3Object --+
                                |
           baseObjects.IndexStore --+
                                    |
               object --+           |
                        |           |
    configParser.C3Object --+       |
                            |       |
        baseStore.SimpleStore --+   |
                                |   |
                    PostgresStore --+
                                    |
                                   PostgresIndexStore

Instance Methods

__init__(self, session, config, parent) The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object.
generate_tableName(self, session, index)
contains_index(self, session, index) Does the IndexStore currently store the given Index.
create_index(self, session, index) Create an index in the store.
begin_indexing(self, session, index) Perform tasks as required before indexing begins, for example setting batch files.
commit_indexing(self, session, index) Commit the data to disk from the indexing process.
store_terms(self, session, index, termhash, record) Store terms in the index for a given record.
fetch_term(self, session, index, term, prox=True) Fetch a single term.
fetch_termList(self, session, index, term) Fetch a list of terms for an index.
_cql_to_sql(self, session, query, pm)
search(self, session, query, db)
Inherited from `baseObjects.IndexStore`: `clean_index`, `delete_index`, `delete_terms`, `fetch_indexList`, `fetch_indexStats`, `fetch_sortValue` Inherited from `PostgresStore`: `begin_storing`, `commit_storing`, `delete_item`, `fetch_checksum`, `fetch_data`, `fetch_idList`, `fetch_size`, `generate_id`, `get_links`, `link`, `query`, `store_checkSum`, `store_data`, `unlink`, `verify_checkSum` Inherited from `PostgresStore` (private): `_closeContainer`, `_handleConfigNode`, `_openContainer`, `_verifyDatabases` Inherited from `configParser.C3Object`: `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

database |
transaction |
Inherited from `PostgresStore`: `cxn`, `relations` Inherited from `baseStore.SimpleStore`: `currentId`, `idNormalizer` Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### __init__(self, session, config, parent) (Constructor) | source code
The constructor for all Cheshire3 objects take the same arguments: session: A Session object topNode: The <config> or <subConfig> domNode for the configuration parent: The object that provides the scope for this object. Overrides: PostgresStore.__init__

### generate_tableName(self, session, index) | source code

### contains_index(self, session, index) | source code
Does the IndexStore currently store the given Index. Overrides: baseObjects.IndexStore.contains_index (inherited documentation)

### create_index(self, session, index) | source code
Create an index in the store. Overrides: baseObjects.IndexStore.create_index (inherited documentation)

### begin_indexing(self, session, index) | source code
Perform tasks as required before indexing begins, for example setting batch files. Overrides: baseObjects.IndexStore.begin_indexing (inherited documentation)

### commit_indexing(self, session, index) | source code
Commit the data to disk from the indexing process. Overrides: baseObjects.IndexStore.commit_indexing (inherited documentation)

### store_terms(self, session, index, termhash, record) | source code
Store terms in the index for a given record. Overrides: baseObjects.IndexStore.store_terms (inherited documentation)

### fetch_term(self, session, index, term, prox=True) | source code
Fetch a single term. Overrides: baseObjects.IndexStore.fetch_term (inherited documentation)

### fetch_termList(self, session, index, term) | source code
Fetch a list of terms for an index. numReq: How many terms are wanted. relation: Which order to scan through the index. end: A point to end at (eg between A and B) summary: Only return frequency info, not the pointers to matching records. reverse: Use the reversed index if available (eg 'xedni' not 'index'). Overrides: baseObjects.IndexStore.fetch_termList (inherited documentation)

### _cql_to_sql(self, session, query, pm) | source code

### search(self, session, query, db) | source code

Class Variable Details

    ### database Value:
        ''

    ### transaction Value:
        0